cacp.comparison
----------------------

.. automodule:: cacp.comparison
    :members:
    :undoc-members:
    :show-inheritance:

cacp.dataset
-------------------

.. automodule:: cacp.dataset
    :members:
    :undoc-members:
    :show-inheritance:

cacp.info
----------------

.. automodule:: cacp.info
    :members:
    :undoc-members:
    :show-inheritance:

cacp.plot
----------------

.. automodule:: cacp.plot
    :members:
    :undoc-members:
    :show-inheritance:

cacp.result
------------------

.. automodule:: cacp.result
    :members:
    :undoc-members:
    :show-inheritance:

cacp.run
---------------

.. automodule:: cacp.run
    :members:
    :undoc-members:
    :show-inheritance:

cacp.time
----------------

.. automodule:: cacp.time
    :members:
    :undoc-members:
    :show-inheritance:

cacp.util
----------------

.. automodule:: cacp.util
    :members:
    :undoc-members:
    :show-inheritance:

cacp.wilcoxon
--------------------

.. automodule:: cacp.wilcoxon
    :members:
    :undoc-members:
    :show-inheritance:

cacp.winner
------------------

.. automodule:: cacp.winner
    :members:
    :undoc-members:
    :show-inheritance:

